OC.L10N.register(
    "spreed",
    {
    "a conversation" : "una conversación",
    "(Duration %s)" : "(Duración %s)",
    "You attended a call with {user1}" : "Tomaste una llamda con {user1}",
    "_%n guest_::_%n guests_" : ["%n inivitado","%n inivitados"],
    "You attended a call with {user1} and {user2}" : "Tuviste una llamada con {user1} y {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Tuviste una llamada con {user1}, {user2} y {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Tuviste una llamada con {user1}, {user2}, {user3} y {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Tuviste una llamada con {user1}, {user2}, {user3}, {user4} y {user5}",
    "_%n other_::_%n others_" : ["%n otro","otros %n"],
    "{actor} invited you to {call}" : "{actor} te ha invitado a {call}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Fuiste invitado a una<strong>conversación</strong> o tuviste una <strong>llamada</strong>",
    "Talk" : "Hablar",
    "Guest" : "Invitado",
    "Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "Bienvenido a Nextcloud Talk!\nEn esta conversación se te informará sobre nuevas características disponibles en Nextcloud Talk.",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Microsoft Edge y Safari ahora pueden ser usados para participar en llamdas de audio y video llamadas",
    "- One-to-one conversations are now persistent and can not be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- Coversaciones uno-a-uno ahora son persistentes y ya no pueden ser convertidas en conversaciones de grupo por accidente. Además cuando uno de los participantes abandona la conversación, la conversación ya no es eliminada automáticamente. Solo si ambos participantes abandonan la conversación, la conversación es eliminada del servidor.",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- Ahora puedes notificar a todos los participantes comentando \"@all\" en el chat",
    "- With the \"arrow-up\" key you can repost your last message" : "- Puedes reenviar tu último mensaje con la tecla \"flecha arriba\"",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Talk ahora puede recibir comandos, envia \"/help\" como mensaje en el chat para ver si tu administrador configuro algunos",
    "- With projects you can create quick links between conversations, files and other items" : "- Con projects puedes crear ligas entre conversaciones, archivos y otros artículos.",
    "New in Talk 7" : "Nuevo en Talk 7",
    "- You can now mention guests in the chat" : "- Ahora puedes mencionar a invitados en el chat",
    "There are currently no commands available." : "No hay comandos disponibles actualmente",
    "The command does not exist" : "El comando no existe",
    "An error occurred while running the command. Please ask an administrator to check the logs." : "Ocurrió un error al ejecutar el comando. Por favor solicite al administrador revisar los logs",
    "Talk updates ✅" : "Actualizaciones de Talk  ✅",
    "{actor} created the conversation" : "{actor} creó la conversación",
    "You created the conversation" : "Creaste la conversación",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} renombró la conversación de \"%1$s\" a \"%2$s\"",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Renombraste la conversación de \"%1$s\" a \"%2$s\"",
    "{actor} started a call" : "{actor} inició una llamada",
    "You started a call" : "Iniciaste una llamada",
    "{actor} joined the call" : "{actor} se unió a la llamada",
    "You joined the call" : "Te uniste a la llamada",
    "{actor} left the call" : "{actor} abandonó la llamada",
    "You left the call" : "Abandonaste la llamada",
    "{actor} unlocked the conversation" : "{actor} desbloqueó la conversación",
    "You unlocked the conversation" : "Desbloqueaste la conversación",
    "{actor} locked the conversation" : "{actor} bloqueó la conversación",
    "You locked the conversation" : "Bloqueaste la conversación",
    "The conversation is now open to everyone" : "La conversación está abierta para todos",
    "{actor} opened the conversation to everyone" : "{actor} abrió la conversación para todos",
    "You opened the conversation to everyone" : "Abriste la conversación para todos",
    "{actor} restricted the conversation to moderators" : "{actor} restringió la conversación a moderadores",
    "You restricted the conversation to moderators" : "Restringiste la conversación a moderadores",
    "{actor} allowed guests" : "{actor} permitió a invitados",
    "You allowed guests" : "Permitiste a invitados",
    "{actor} disallowed guests" : "{actor} restringió a invitados",
    "You disallowed guests" : "Restringiste a invitados",
    "{actor} set a password" : "{actor} configuró una contraseña",
    "You set a password" : "Configuraste una contraseña",
    "{actor} removed the password" : "{actor} eliminó la contraseña",
    "You removed the password" : "Eliminaste la contraseña",
    "{actor} added {user}" : "{actor} agregó a {user}",
    "You joined the conversation" : "Te uniste a la conversación",
    "{actor} joined the conversation" : "{actor} se unió a la conversación",
    "You added {user}" : "Agregaste a  {user}",
    "{actor} added you" : "{actor} te agregó",
    "You left the conversation" : "Abandonaste la conversación",
    "{actor} left the conversation" : "{actor} abandonó la conversación",
    "{actor} removed {user}" : "{actor} eliminó a {user}",
    "You removed {user}" : "Eliminaste a {user}",
    "{actor} removed you" : "{actor} te eliminó",
    "{actor} promoted {user} to moderator" : "{actor} promovió a {user} a moderador",
    "You promoted {user} to moderator" : "Promoviste a  {user} a moderador",
    "{actor} promoted you to moderator" : "{actor} te promovió a moderador",
    "{actor} demoted {user} from moderator" : "{actor} degradó a {user} de moderador",
    "You demoted {user} from moderator" : "Degradaste a {user} de moderador",
    "{actor} demoted you from moderator" : "{actor} te degradó de moderador",
    "{actor} shared a file which is no longer available" : "{actor} compartió un archivo que ya no está disponible",
    "You shared a file which is no longer available" : "Compartiste un archivo que ya no está disponible",
    "%s (guest)" : "%s (invitado)",
    "_Call with %n guest (Duration {duration})_::_Call with %n guests (Duration {duration})_" : ["Llamada con %n invitado (Duración {duration})","Llamada con %n invitados (Duración {duration})"],
    "Call with {user1} and {user2} (Duration {duration})" : "Llamada con {user1} y {user2} (Duración {duration})",
    "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Llamada con {user1}, {user2} y {user3} (Duración {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Llamada con {user1}, {user2}, {user3} y {user4} (Duración {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Llamada con {user1}, {user2}, {user3}, {user4} y {user5} (Duración {duration})",
    "Talk to %s" : "Hablar con %s",
    "File is not shared, or shared but not with the user" : "Archivo no compartido, o compartido pero no con el usuario.",
    "%s invited you to a conversation." : "%s te invitó a una conversación",
    "You were invited to a conversation." : "fuiste invitado a una conversación",
    "Conversation invitation" : "invitación a una conversación",
    "Click the button below to join." : "Haz click en el botón de abajo para unirte.",
    "Join »%s«" : "Unirse »%s«",
    "Password request: %s" : "Solicitud de Password: %s",
    "Private conversation" : "Conversación privada",
    "Deleted user (%s)" : "Usuario eliminado (%s)",
    "{user} sent you a private message" : "{user} te envió un mensaje privado",
    "{user} mentioned you in a private conversation" : "{user} te mencionó en una conversación privada",
    "{user} invited you to a private conversation" : " {user} te invitó a una conversación privada",
    "Join call" : "Unirse a la llamada",
    "{user} invited you to a group conversation: {call}" : "{user} te invitó a una conversación de grupo: {call}",
    "{user} wants to talk with you" : "{user} quiere hablar contigo",
    "A group call has started in {call}" : "Una llamada en grupo ha iniciado en {call}",
    "Invalid date, date format must be YYYY-MM-DD" : "La fecha es inválida, por favor sigue el formato AAAA-MM-DD",
    "Leave call" : "Dejar la llamada",
    "This conversation has ended" : "Esta conversación ha terminado",
    "Limit to groups" : "Limitar a grupos",
    "Everyone" : "Todos",
    "Save changes" : "Guardar cambios",
    "Saved!" : "¡Guardado!",
    "None" : "Ninguno",
    "User" : "Usuario",
    "Disabled" : "Deshabilitado",
    "Users" : " Usuarios",
    "Name" : "Nombre",
    "General settings" : "Configuraciones generales",
    "Validate SSL certificate" : "Validar certificado SSL",
    "Saved" : "Guardado",
    "Shared secret" : "Secreto compartido",
    "STUN servers" : "Servidores STUN",
    "A STUN server is used to determine the public IP address of participants behind a router." : "Un servidor STUN se está usando para determinar la IP pública de los participantes que estén detrás de un ruteador. ",
    "TURN server protocols" : "Protocolos del servidor TURN",
    "UDP and TCP" : "UDP y TCP",
    "UDP only" : "UDP únicamente",
    "TCP only" : "TCP únicamente",
    "Copy link" : "Copiar liga",
    "Waiting for others to join the call …" : "Esperando a que los demás se unan a la llamada ...",
    "You can invite others in the participant tab of the sidebar" : "Puedes invitar a otras personas en la pestaña de participante del menú lateral",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "¡Puedes invitar a otros usando la pestaña de participante de la barra lateral o compartiendo esta liga para invitar a otras personas!",
    "Share this link to invite others!" : "¡Comparte esta liga para invitar a otras personas!",
    "Show your screen" : "Mostrar tu pantalla",
    "Stop screensharing" : "Dejar de compartir la pantalla",
    "No audio" : "Sin audio",
    "Mute audio (m)" : "Silenciar audio (m)",
    "Unmute audio (m)" : "Habilitar audio (m)",
    "Mute audio" : "Silenciar audio",
    "Disable video (v)" : "Deshabilitar video (v)",
    "Enable video (v)" : "Habilitar video (v)",
    "Disable video" : "Deshabilitar video",
    "Enable video" : "Habilitar el video",
    "Screensharing options" : "Opciones de compartir pantalla",
    "Enable screensharing" : "Habilitar compartir pantalla",
    "Screensharing requires the page to be loaded through HTTPS." : "Compartir pantalla requiere que la página se cargue a través de HTTPS.",
    "Sharing your screen only works with Firefox version 52 or newer." : "Compartir la pantalla sólo funciona con Firefox versión 52 o superior. ",
    "Screensharing extension is required to share your screen." : "Se requiere de la extenisón de compartir pantalla para compartir tu pantalla. ",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Por favor usa un navegador diferente como Firefox o Chrome para compartir tu pantalla.",
    "An error occurred while starting screensharing." : "Se presentó un error al comenzar a compartir la pantalla. ",
    "You" : "Tú",
    "Show screen" : "Mostrar pantalla",
    "Favorite" : "Hacer favorito",
    "Leave conversation" : "Dejar la conversación",
    "Delete conversation" : "Borrar conversación",
    "Remove from favorites" : "Eliminar de favoritos",
    "Add to favorites" : "Agregar a favoritos",
    "Conversations" : "Conversaciones",
    "Loading" : "Cargando",
    "Groups" : "Grupos",
    "Circles" : "Círculos",
    "Error" : "Error",
    "Password protect" : "Proteger con contraseña",
    "Back" : "Atrás",
    "Close" : "Cerrar",
    "Conversation name" : "Nombre de la conversación",
    "Reply" : "Responder",
    "Today" : "Hoy",
    "Yesterday" : "Ayer",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "moderator" : "moderador",
    "guest" : "invitado",
    "Demote from moderator" : "Degradar de moderador",
    "Promote to moderator" : "Promover a moderador",
    "Remove participant" : "Eliminar participante",
    "No results" : "Sin resultados",
    "Add users or groups" : "Agregar usuarios o grupos",
    "Participants" : "Participantes",
    "Chat" : "Chat",
    "Settings" : "Configuraciones ",
    "Edit" : "Editar",
    "Dismiss" : "Descartar",
    "Rename conversation" : "Renombrar conversación",
    "Share link" : "Compartir liga",
    "Password protection" : "Protección con contraseña",
    "Enter a password" : "Ingresa una contraseña",
    "Exit fullscreen (f)" : "Salir de pantalla completa (f)",
    "Fullscreen (f)" : "Pantalla completa (f)",
    "Grid view" : "Vista de cuadrícula",
    "Join a conversation or start a new one" : "Únete a la conversación o incia una nueva",
    "Access to microphone & camera is only possible with HTTPS" : "El acceso al micrófono & cámara sólo es posible mediante HTTPS",
    "Please move your setup to HTTPS" : "Por favor cambia tu configuración a HTTPS",
    "Access to microphone & camera was denied" : "El acceso al micrófono & cámara fue denegado",
    "WebRTC is not supported in your browser" : "WebRTC no está soportado en tu navegador",
    "Please use a different browser like Firefox or Chrome" : "Por favor usa un navegador diferente como Firefox o Chrome",
    "Error while accessing microphone & camera" : "Se pressentó un error al acceder al micrófono & cámara",
    "The password is wrong. Try again." : "La contraseña está equivoada. Por favor vuelve a intentarlo. ",
    "Password" : "Contraseña",
    "TURN server" : "Servidor TURN",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "El servidor TURN se usa para concentrar el tráfico de participantes detras de un firewall. ",
    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Un servidor externo de señalización puede ser, opcionalmente, utilizado para instalaciones más grandes. Déjalo vacío para usar el sevidor de señalización interno. ",
    "%s Talk on your mobile devices" : "%s Habla en tus dispositivos móviles",
    "Android app" : "Aplicación Android",
    "iOS app" : "Aplicación iOS",
    "New conversation …" : "Nueva conversación ...",
    "Copy" : "Copiar",
    "Copied!" : "¡Copiado!",
    "Not supported!" : "¡No soportado!",
    "Press ⌘-C to copy." : "Presiona ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Presiona Ctrl-C para copiar.",
    "Please enter the password for this call" : "Por favor ingresa la contraseña para esta llamada",
    "Password required" : "Contraseña requerida",
    "Cancel" : "Cancelar",
    "Submit" : "Enviar",
    "Guests" : "Invitados",
    "Change password" : "Cambiar contraseña",
    "Set password" : "Establecer contraseña",
    "Rename" : "Renombrar",
    "Link copied!" : "¡Liga copiada!",
    "Conversation with {name}" : "Conversación con {name}",
    "Error occurred while setting password" : "Se presentó un error al establecer al contraseña",
    "No messages yet, start the conversation!" : "Aún no hay mensajes. ¡!Inicia la conversación!",
    "New message …" : "Mensaje nuevo ...",
    "Send" : "Enviar",
    "Share" : "Compartir",
    "[Unknown user name]" : "[Nombre de usuario desconocido]",
    "Error occurred while sending message" : "Se presentó un error al enviar el mensaje",
    "Error while sharing" : "Se presentó un error al compartir",
    "No other people in this call" : "No hay más personas en esta llamada",
    "Waiting for {participantName} to join the call …" : "Esperando a que {participantName} se una a la llamada…",
    "WebRTC is not supported in your browser :-/" : "WebRTC no se encuentra soportado en tu navegador :-/",
    "Waiting for camera and microphone permissions" : "Aguardando los permisos para la cámara y micrófono",
    "Please, give your browser access to use your camera and microphone in order to use this app." : "Por favor da acceso a tu navegador para usar tu camara y micrófono poder usar esta aplicación. ",
    "Share screen" : "Compartir la pantalla",
    "No Camera" : "Sin cámara",
    "Screensharing is not supported by your browser." : "Compartir pantalla no está soportado por tu navegador. ",
    "Add participant …" : "Agregar participante ...",
    "Favorited" : "Marcado como favorito",
    "Your screen" : "Tu pantalla",
    "{participantName}'s screen" : "Pantalla de {participantName}",
    "Guest's screen" : "Pantalla del invitado",
    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait." : "- Las conversaciones ahora pueden tener un lobby. Esto permitirá a moderadores preparar el char y llamadas para jutas, mientras usuarios e invitados esperan.",
    "Join conversations at any time, any where, on any device." : "Únete a conversaciones en cualquier momento, en cualquier lugar, en cualquier dispositivo.",
    "Contacts" : "Contactos"
},
"nplurals=2; plural=(n != 1);");
